@@ -50,6 +50,10 @@ class ValidationError(WebargsError):
             self.message, self.status_code
         )
 
+class RequiredArgMissingError(ValidationError):
+    """Raised when a required argument is not found no a request."""
+    pass
+
 
 def _callable_or_raise(obj):
     """Makes sure an object is callable if it is not ``None``. If not
@@ -85,7 +89,7 @@ class _Missing(object):
     __nonzero__ = __bool__  # py2 compatibility
 
     def __repr__(self):
-        return '<webargs.core.missing>'
+        return '<webargs.core.Missing>'
 
 
 #: Singleton object that represents a value that cannot be found on a request.
@@ -101,7 +105,7 @@ def get_value(d, name, multiple):
     :param bool multiple: Whether to handle multiple values.
     """
     val = d.get(name, Missing)
-    if multiple:
+    if multiple and val is not Missing:
         if hasattr(d, 'getlist'):
             return d.getlist(name)
         elif hasattr(d, 'getall'):
@@ -222,13 +226,15 @@ class Arg(object):
                 raise ValidationError(self.error or msg)
 
         if self._has_nesting:
+            # Filter out extra args
+            ret = dict((k, v) for k, v in iteritems(ret) if k in self._nested_args)
             # Recurse into nested argdict
             for key, nested_arg in iteritems(self._nested_args):
                 try:
                     val = ret[key]
                 except KeyError:
                     if nested_arg.required:
-                        raise ValidationError(
+                        raise RequiredArgMissingError(
                             'Required parameter "{0}" not found.'.format(key)
                         )
                 else:
@@ -346,7 +352,9 @@ class Parser(object):
                 else:
                     value = argobj.default
             if argobj.required:
-                raise ValidationError('Required parameter "{0}" not found.'.format(name))
+                raise RequiredArgMissingError(
+                    'Required parameter "{0}" not found.'.format(name)
+                )
         return value
 
     def parse(self, argmap, req, targets=None, validate=None, force_all=False):
